@@ -373,13 +373,11 @@ class SqlAlchemyProxy:
     def onChange(self, model):
         if ObjectHelper.isNone(model):
             return model
+        elif isinstance(model, PythonFramworkBaseClass):
+            model.onChange(eventType=OnORMChangeEventType.IMPLEMENTED_QUERY)
         elif ObjectHelper.isCollection(model) or type(model) == InstrumentedList:
             for m in model:
                 self.onChange(m)
-            return model
-        elif isinstance(model, PythonFramworkBaseClass):
-            model.onChange(eventType=OnORMChangeEventType.IMPLEMENTED_QUERY)
-            return model
         return model
 
     @Method
@@ -433,6 +431,12 @@ class SqlAlchemyProxy:
         self.session.commit()
         return self.onChange(instance)
 
+    @Method
+    def findAllByIdAndCommit(self, id, modelClass):
+        instanceList = self.session.query(modelClass).filter(modelClass.id == id).all()
+        self.session.commit()
+        return self.onChange(instanceList)
+
     @Method
     def findAllByIdInAndCommit(self, idList, modelClass):
         instanceList = self.session.query(modelClass).filter(modelClass.id.in_(idList)).all()
@@ -452,6 +456,12 @@ class SqlAlchemyProxy:
         self.session.commit()
         return self.onChange(instance)
 
+    @Method
+    def findAllByKeyAndCommit(self, key, modelClass):
+        instanceList = self.session.query(modelClass).filter(modelClass.key == key).all()
+        self.session.commit()
+        return self.onChange(instanceList)
+
     @Method
     def findAllByKeyInAndCommit(self, keyList, modelClass):
         instanceList = self.session.query(modelClass).filter(modelClass.key.in_(keyList)).all()
@@ -470,6 +480,12 @@ class SqlAlchemyProxy:
         self.session.commit()
         return self.onChange(instance)
 
+    @Method
+    def findAllByStatusAndCommit(self,status,modelClass):
+        instanceList = self.session.query(modelClass).filter(modelClass.status == status).all()
+        self.session.commit()
+        return self.onChange(instanceList)
+
     @Method
     def findAllByStatusInAndCommit(self, statusList, modelClass):
         instanceList = self.session.query(modelClass).filter(modelClass.status.in_(statusList)).all()
